summaryrefslogtreecommitdiff
path: root/drivers/gpu/msm
diff options
context:
space:
mode:
authorHarshdeep Dhatt <hdhatt@codeaurora.org>2016-11-03 14:43:27 -0600
committerHarshdeep Dhatt <hdhatt@codeaurora.org>2016-11-07 16:17:04 -0700
commitc2682f2a0624938276fa45224ee4acc6436951ff (patch)
treec32961c54c68533a8edcc81d67f86d4c5752e0b8 /drivers/gpu/msm
parente1f711f8e00cb745202f18fb97fb93ef38a615c2 (diff)
msm: kgsl: Increase fault detection threshold value
The current value is leading to spurious fault interrupts from the GPU. Increase the threshold 4 times so that hardware fault detection won't be triggered as quickly. CRs-Fixed: 1073836 Change-Id: Ie780cec4de818c94a407461580f9d80de7e4ec84 Signed-off-by: Harshdeep Dhatt <hdhatt@codeaurora.org>
Diffstat (limited to 'drivers/gpu/msm')
-rw-r--r--drivers/gpu/msm/adreno_a5xx.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/gpu/msm/adreno_a5xx.c b/drivers/gpu/msm/adreno_a5xx.c
index 860f6d2925f1..986adb5fef65 100644
--- a/drivers/gpu/msm/adreno_a5xx.c
+++ b/drivers/gpu/msm/adreno_a5xx.c
@@ -1781,11 +1781,11 @@ static void a5xx_start(struct adreno_device *adreno_dev)
set_bit(ADRENO_DEVICE_HANG_INTR, &adreno_dev->priv);
gpudev->irq->mask |= (1 << A5XX_INT_MISC_HANG_DETECT);
/*
* Set hang detection threshold to 1 million cycles
* (0xFFFF*16)
*/
kgsl_regwrite(device, A5XX_RBBM_INTERFACE_HANG_INT_CNTL,
- (1 << 30) | 0xFFFF);
+ (1 << 30) | 0x3FFFF);
}
@@ -1781,11 +1781,11 @@ static void a5xx_start(struct adreno_device *adreno_dev)
gpudev->irq->mask |= (1 << A5XX_INT_MISC_HANG_DETECT);
/*
- * Set hang detection threshold to 1 million cycles
- * (0xFFFF*16)
+ * Set hang detection threshold to 4 million cycles
+ * (0x3FFFF*16)
*/
kgsl_regwrite(device, A5XX_RBBM_INTERFACE_HANG_INT_CNTL,